/*!
 * \brief
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENCFDDEF_H
#define CAENCFDDEF_H

#include <CAENDigitizer.h>

#include "common/base/BaseTypes.h"

namespace caen_cfd {

// Board parameters
typedef struct {
    CAEN_DGTZ_ConnectionType 	LinkType;				// Type of connection
    int32 						VMEBaseAddress;			// VME address
    CAEN_DGTZ_AcqMode_t			AcqMode;				// Start acquisition mode (SW, S_IN, First trigger)
    CAEN_DGTZ_DPP_AcqMode_t		DPPAcqMode;				// Acquisition mode (Oscilloscope, List, Mixed)
    CAEN_DGTZ_DPP_SaveParam_t 	SaveMode;				// Save mode (Energy, Time, Energy&Time, None)
    int32 						RecordLength;			// Nb of samples in oscilloscope mode
    int32 						cfdTrap;				// Enable CFD plot or trapezoid
    CAEN_DGTZ_IOLevel_t			IOLevel;				// I/O level (NIM, TTL)
    CAEN_DGTZ_TriggerMode_t		TriggerMode;			// Trigger mode (disable, extout, acq_only, acq_extout)
    int32 						ChannelMask;			// Channel enable mask
    int32 						EventAggr;				// Nb of events per aggregate (0=automatic)
} DigitizerParams_t;

#define CFD_FAKEEVTS_ROLLOVER_REG 0X1080
#define DPP_ALG_CTRL2_REG 0X10A0
#define CFD_BASELINE_REG 0X10D0
#define CFD_DELAY_REG 0X1058
#define DYNAMIC_RANGE_REG 0X1028


}

#endif // CAENCFDDEF_H
