/*!
 * \brief
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENQDCDEF_H
#define CAENQDCDEF_H

#include <CAENDigitizer.h>

#include "common/base/BaseTypes.h"

namespace caen_qdc {

// Board parameters
typedef struct {
	uint32_t LinkType;
    uint32_t VMEBaseAddress;
	uint32_t RecordLength;
	uint32_t PreTrigger;
	uint32_t ActiveChannel;
	uint32_t GateWidth[8];
	uint32_t PreGate;
	uint32_t ChargeSensitivity;
	uint32_t FixedBaseline;
	uint32_t BaselineMode;
    uint32_t TrgMode;
    uint32_t TrgSmoothing;
    uint32_t TrgHoldOff;
    uint32_t TriggerThreshold[64];
	uint32_t DCoffset[8];
	uint32_t AcqMode;
	uint32_t NevAggr;
    uint32_t PulsePol;
    uint32_t EnChargePed;
    uint32_t SaveList;
    uint32_t DisTrigHist;
    uint32_t DisSelfTrigger;
    uint32_t EnTestPulses;
    uint32_t TestPulsesRate;
    uint32_t DefaultTriggerThr;
    uint32_t EnableExtendedTimeStamp;
	uint64_t ChannelTriggerMask;
} DigitizerParams_t;

#define MAX_AGGR_NUM_PER_BLOCK_TRANSFER   	1023 		// Max 1023
#define MAX_NB_GROUP   						8
#define ACQMODE_LIST    					0
#define ACQMODE_MIXED   					1
#define V1740_MAX_CHANNELS					64

}

#endif // CAENQDCDEF_H
