/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef REALCAENQDCDRIVER_H
#define REALCAENQDCDRIVER_H

#include <CAENDigitizer.h>

#include "CAENQdcDef.h"
#include "CAENQdcState.h"

namespace caen_qdc {

class CAENQdcDriver;

/**
 * Real implementation
 */
class RealCAENQdcDriver : public CAENQdcState {

public:

	/**
	 * Constructor.
	 *
	 * @param Link to the class which used the state
	 */
	RealCAENQdcDriver(CAENQdcDriver* owner);

	/**
	 * Destructor.
	 * Empty.
	 */
	virtual ~RealCAENQdcDriver();

	/*!
	 * \brief Init command implementation
	 */
	virtual void init();

	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear();

	/*!
	 * \brief Reset command implementation
	 */
	virtual void reset();

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Set acquisition mode command implementation
	 */
	virtual void setAcqMode();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

private:

	void open();
	void close();

	int32_t getChannelAddress(uint32_t base, uint16_t channel);
	int32_t setChannelTriggerThreshold(uint32_t channel, uint32_t Tvalue);
	int32_t setRecordLength(uint32_t recordLength);
	int32_t setNumEvAggregate(uint32_t nevAggr);
	int32_t setChannelGroupMask(uint32_t group, uint32_t channelmask);
	int32_t setGroupTriggerMask(uint32_t group, uint32_t channelmask);

	int32_t m_boardHandle;

	int32_t ret;

	CAEN_DGTZ_BoardInfo_t boardInfo;
	DigitizerParams_t boardParams;
	CAEN_DGTZ_DPP_PSD_Params_t dppParams;
};

}
#endif //REALCAENQDCDRIVER_H
