/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENSY2527BOARDSTATE_H
#define CAENSY2527BOARDSTATE_H

#include <Driver.h>

#include "CAENSy2527BoardDriver.h"

namespace caen_sy2527 {

/*!
 * \class CAENVSy2527BoardlState
 * \brief Implements State pattern
 */
class CAENSy2527BoardState : public DriverState<CAENSy2527BoardDriver> {

public:

	/*!
	 * \brief Constructor.
	 */
	CAENSy2527BoardState(CAENSy2527BoardDriver* owner) :
		DriverState<CAENSy2527BoardDriver> (owner) {
	}

	/*!
	 * \brief Destructor.
	 */
	virtual ~CAENSy2527BoardState() {};

	/*!
	 * \brief Init.
	 */
	virtual void init() = 0;

	/*!
	 * \brief Read.
	 */
	virtual void read() = 0;

	/*!
	 * \brief Read parameters.
	 */
	virtual void readParam() = 0;

	/*!
	 * \brief Write parameters.
	 */
	virtual void writeParam() = 0;

	/*!
	 * \brief Start ramp.
	 */
	virtual void start() = 0;

	/*!
	 * \brief Stop current action.
	 */
	virtual void stop() = 0;

	/*!
	 * \brief Read status.
	 */
	virtual void readStatus() = 0;

	/*!
	 * \brief Power on.
	 */
	virtual void powerOn() = 0;

	/*!
	 * \brief Power off.
	 */
	virtual void powerOff() = 0;

};

}

#endif //CAENSY2527BOARDSTATE_H
