/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENSY2527STATE_H
#define CAENSY2527STATE_H

#include <Driver.h>

#include "CAENSy2527Driver.h"

namespace caen_sy2527 {

/*!
 * \class CAENPhaState
 * \brief Implements State pattern
 */
class CAENSy2527State: public DriverState<CAENSy2527Driver> {

public:

	/*!
	 * \brief Constructor.
	 */
	CAENSy2527State(CAENSy2527Driver* owner) :
		DriverState<CAENSy2527Driver> (owner) {}

	/*!
	 * \brief Destructor.
	 */
	virtual ~CAENSy2527State() {}

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos() = 0;

	/**
	 * Read actual values.
	 */
	virtual void read(CAENSy2527BoardDriver* aBoard) = 0;

	/*!
	 * \brief Read parameters.
	 */
	virtual void readParam(CAENSy2527BoardDriver* aBoard) = 0;

	/*!
	 * \brief Write parameters.
	 */
	virtual void writeParam(CAENSy2527BoardDriver* aBoard) = 0;

	/*!
	 * \brief Start ramp.
	 */
	virtual void start(CAENSy2527BoardDriver* aBoard) = 0;

	/*!
	 * \brief Stop ramp.
	 */
	virtual void stop(CAENSy2527BoardDriver* aBoard) = 0;

	/*!
	 * \brief Read status.
	 */
	virtual void readStatus(CAENSy2527BoardDriver* aBoard) = 0;

	/*!
	 * \brief Power on.
	 */
	virtual void powerOn(CAENSy2527BoardDriver* aBoard) = 0;

	/*!
	 * \brief Power off.
	 */
	virtual void powerOff(CAENSy2527BoardDriver* aBoard) = 0;
};

}

#endif //CAENSY2527STATE_H
