/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef REALCAENSY2527BOARDDRIVER_H
#define REALCAENSY2527BOARDDRIVER_H

#include "CAENSy2527BoardState.h"

namespace caen_sy2527 {

class CAENSy2527BoardDriver;

/**
 * Real implementation of the CAEN SY2527 HV Boards
 */
class RealCAENSy2527BoardDriver : public CAENSy2527BoardState {

public:

	/**
	 * Constructor.
	 *
	 * @param Link to the class which used the state
	 */
	RealCAENSy2527BoardDriver(CAENSy2527BoardDriver* owner);

	/**
	 * Destructor.
	 * Empty.
	 */
	virtual ~RealCAENSy2527BoardDriver();

	/**
	 * Perform a init.
	 */
	virtual void init();

	/**
	 * Perform a start.
	 */
	virtual void start();

	/**
	 * Perform a read.
	 */
	virtual void read();

	/**
	 * Perform a readParam.
	 */
	virtual void readParam();

	/**
	 * Perform a writeParam.
	 */
	virtual void writeParam();

	/**
	 * Stop
	 */
	virtual void stop();

	/**
	 * Read Status
	 */
	virtual void readStatus();

	/**
	 * power on.
	 */
	virtual void powerOn();

	/**
	 * power off.
	 */
	virtual void powerOff();

};

}

#endif //REALCAENSY2527BOARDDRIVER_H
