/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include <drivers/ioxos/cadaracheacq/CadaracheAcqDef.h>
#include <drivers/ioxos/cadaracheacq/PerfectCadaracheAcqDriver.h>

using namespace acquisition;
using namespace std;

namespace cadaracheacq {

/*
 * Constructor
 */
PerfectCadaracheAcqDriver::PerfectCadaracheAcqDriver(CadaracheAcqDriver* owner) :
		CadaracheAcqState(owner)

{
	/* Empty */
}

/*
 * Destructor
 */
PerfectCadaracheAcqDriver::~PerfectCadaracheAcqDriver() {
	/* Empty */
}

/*
 * init
 */
void PerfectCadaracheAcqDriver::init() {
	readInfos();
}

/*
 * writeParam
 */
void PerfectCadaracheAcqDriver::writeParam() {
}

/*
 * readInfos
 */
void PerfectCadaracheAcqDriver::readInfos() {
	uint32 version = 0xDC010811;
	ostringstream buf;
	buf << hex << version << dec;
	owner()->version.update(buf.str());
}

/*
 *stop
 */
void PerfectCadaracheAcqDriver::start() {
	// Start command
	owner()->actualSlice = owner()->nbSlicesAcq();
	owner()->nbRepaint = owner()->nbRepaint.setpoint();
}

/*
 *stop
 */
void PerfectCadaracheAcqDriver::pause() {
}

/*
 *resum
 */
void PerfectCadaracheAcqDriver::resume() {
}

/*
 *stop
 */
void PerfectCadaracheAcqDriver::stop() {
}

/*
 * readParam
 */
void PerfectCadaracheAcqDriver::readParam() {
}

/*
 * synchroniseRead
 */
void PerfectCadaracheAcqDriver::synchroniseRead() {
	read();
	owner()->m_SynchroniseReadTerminated = true;
}

/*
 * read
 */
void PerfectCadaracheAcqDriver::read() {
	float64 sum = 0;
	int32* data = owner()->data();
	for(int32 i = 0;i < owner()->nbSlicesAcq();++i) {
		data[i] += 1;
		sum += data[i];
	}
	owner()->sum.update(sum);
	owner()->data.sendEvent();
}

/*
 * clear
 */
void PerfectCadaracheAcqDriver::clear() {
}

/*
 * readStatus
 */
void PerfectCadaracheAcqDriver::readStatus() {
	owner()->startActivated = false;
	owner()->computeGateStatus(0);
	owner()->computeAcquisitionStatus(0);
	if (owner()->m_SynchroniseReadActivated == true) {
		if (owner()->m_SynchroniseReadTerminated == true) {
			owner()->m_SynchroniseReadActivated = false;
			owner()->m_SynchroniseReadTerminated = false;
			owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
		}
	} else {
		owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
	}
}

}
